@@ -21,14 +21,14 @@ generate_meta_package() {
 
 export CONCURRENCY_LEVEL=`grep -c '^processor' /proc/cpuinfo` || die "Can't export."
 
-apt-get -y install wget
+apt-get -y install wget zlib1g-dev debian-keyring
 
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.0-20110207.tar.gz ]
+if [ ! -r ccs-patch-1.8.1-20110401.tar.gz ]
 then
-    wget -O ccs-patch-1.8.0-20110207.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.0-20110207.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.1-20110401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.1-20110401.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -39,7 +39,7 @@ apt-get source linux-image-2.6.32-5-686 || die "Can't install kernel source."
 
 # Apply patches and create kernel config.
 cd linux-2.6-2.6.32 || die "Can't chdir to linux-2.6-2.6.32/ ."
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.0-20110207.tar.gz || die "Can't extract patch."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.1-20110401.tar.gz || die "Can't extract patch."
 patch -p1 < patches/ccs-patch-2.6.32-debian-squeeze.diff || die "Can't apply patch."
 cat /boot/config-2.6.32-5-686 config.ccs > .config || die "Can't create config."
 make -s oldconfig
